@@ -19,18 +19,65 @@ from dbtenv import Dbt, DbtenvError, Environment, Version
 
 logger = dbtenv.LOGGER
 
+DBT_ADAPTER_TYPES = [
+    'bigquery',
+    'clickhouse',
+    'databricks',
+    'databricks',
+    'dremio',
+    'exasol',
+    'firebolt',
+    'firebolt',
+    'materialize',
+    'materialize',
+    'oracle',
+    'postgres',
+    'presto',
+    'redshift',
+    'rockset',
+    'rockset',
+    'singlestore',
+    'singlestore',
+    'snowflake',
+    'spark',
+    'sqlserver',
+    'synapse',
+    'teradata',
+    'teradata',
+    'trino',
+    'trino',
+    'vertica',
+]
 
-def get_installed_pip_dbt_versions(env: Environment) -> List[Version]:
+
+def get_installed_pip_dbt_versions(env: Environment, adapter_type: Optional[str] = None) -> List[Version]:
     if not os.path.isdir(env.venvs_directory):
         return []
-    with os.scandir(env.venvs_directory) as venvs_dir_scan:
-        venvs_prefix_length = len(env.venvs_prefix)
-        possible_versions = (
-            Version(entry.name[venvs_prefix_length:])
-            for entry in venvs_dir_scan
-            if entry.is_dir() and entry.name.startswith(env.venvs_prefix)
-        )
-        return [version for version in possible_versions if PipDbt(env, version).is_installed()]
+    versions = []
+    for entry in os.scandir(env.venvs_directory):
+        if entry.is_dir() and bool(re.search(r"^(dbt-.+)==(.+)$", entry.name)) and (not adapter_type or entry.name.startswith(f"dbt-{adapter_type}==")):
+            versions.append(
+                Version(pip_specifier=entry.name)
+            )
+    return versions
+
+
+def get_pypi_package_metadata(package: str) -> str:
+    package_json_url = f'https://pypi.org/pypi/{package}/json'
+    logger.debug(f"Fetching {package} package metadata from {package_json_url}.")
+    with urllib.request.urlopen(package_json_url) as package_json_response:
+        return json.load(package_json_response)
+
+def get_pypi_package_versions(adapter_type: str) -> List[Version]:
+    package_metadata = get_pypi_package_metadata(f"dbt-{adapter_type}")
+    possible_versions = ((Version(adapter_type=adapter_type, version=version), files) for version, files in package_metadata['releases'].items())
+    return [version for version, files in possible_versions if any(not file['yanked'] for file in files)]
+
+def get_pypi_all_dbt_package_versions() -> List[Version]:
+    versions = []
+    for adapter_type in DBT_ADAPTER_TYPES:
+        versions += get_pypi_package_versions(adapter_type)
+    return versions
 
 
 class PipDbt(Dbt):
@@ -38,7 +85,7 @@ class PipDbt(Dbt):
 
     def __init__(self, env: Environment, version: Version) -> None:
         super().__init__(env, version)
-        self.venv_directory = os.path.join(env.venvs_directory, f'{env.venvs_prefix}{version.pypi_version}')
+        self.venv_directory = os.path.join(env.venvs_directory, version.pip_specifier)
         self._executable: Optional[str] = None
 
     def install(self, force: bool = False, package_location: Optional[str] = None, editable: bool = False) -> None:
@@ -49,6 +96,11 @@ class PipDbt(Dbt):
             else:
                 raise DbtenvError(f"`{self.venv_directory}` already exists.")
 
+        available_adapter_versions = get_pypi_package_versions(adapter_type=self.version.adapter_type)
+        if self.version not in available_adapter_versions:
+            logger.info(f"{self.version} is not available for installation from pypi. Try one of {[v.pypi_version for v in available_adapter_versions]}")
+            return
+
         python = self.env.python
         self._check_python_compatibility(python)
 
@@ -57,53 +109,55 @@ class PipDbt(Dbt):
         if venv_result.returncode != 0:
             raise DbtenvError(f"Failed to create virtual environment in `{self.venv_directory}`.")
 
-        pip = self._find_pip()
-        # Upgrade pip to avoid problems with packages that might require newer pip features.
-        subprocess.run([pip, 'install', '--upgrade', 'pip'])
-        # Install wheel to avoid pip falling back to using legacy `setup.py` installs.
-        subprocess.run([pip, 'install', '--disable-pip-version-check', 'wheel'])
-        pip_args = ['install', '--disable-pip-version-check']
-        if package_location:
-            package_source = f"`{package_location}`"
-            if editable:
-                pip_args.append('--editable')
-            pip_args.append(package_location)
-        else:
-            package_source = "the Python Package Index"
-            if self.env.simulate_release_date:
-                package_metadata = get_pypi_package_metadata('dbt')
-                release_date = date.fromisoformat(package_metadata['releases'][self.version.pypi_version][0]['upload_time'][:10])
-                logger.info(f"Simulating release date {release_date} for dbt {self.version}.")
-                class ReleaseDateFilterPyPIRequestHandler(BaseDateFilterPyPIRequestHandler):
-                    date = release_date
-                pip_filter_server = http.server.HTTPServer(('', 0), ReleaseDateFilterPyPIRequestHandler)
-                pip_filter_port = pip_filter_server.socket.getsockname()[1]
-                threading.Thread(target=pip_filter_server.serve_forever, daemon=True).start()
-                pip_args.extend(['--index-url', f'http://localhost:{pip_filter_port}/simple'])
-            elif self.version < Version('0.19.1'):
-                # Versions prior to 0.19.1 just specified agate>=1.6, but agate 1.6.2 introduced a dependency on PyICU
-                # which causes installation problems, so exclude that like versions 0.19.1 and above do.
-                pip_args.append('agate>=1.6,<1.6.2')
-
-            # Use correct dbt package name depending on version
-            if self.version < Version('1.0.0'):
-                pip_args.append(f'dbt=={self.version.pypi_version}')
+        try:
+            pip = self._find_pip()
+            # Upgrade pip to avoid problems with packages that might require newer pip features.
+            subprocess.run([pip, 'install', '--upgrade', 'pip'])
+            # Install wheel to avoid pip falling back to using legacy `setup.py` installs.
+            subprocess.run([pip, 'install', '--disable-pip-version-check', 'wheel'])
+            pip_args = ['install', '--disable-pip-version-check']
+            if package_location:
+                package_source = f"`{package_location}`"
+                if editable:
+                    pip_args.append('--editable')
+                pip_args.append(package_location)
             else:
-                # See comment on adapter - dbt-core version coordination
-                # https://getdbt.slack.com/archives/C02HM9AAXL4/p1637345945047100?thread_ts=1637323222.046100&cid=C02HM9AAXL4
-                pip_args.append(f'dbt-core=={self.version.pypi_version}')
-                pip_args.append(f'dbt-postgres~={self.version.major_minor_patch}')
-                pip_args.append(f'dbt-redshift~={self.version.major_minor_patch}')
-                pip_args.append(f'dbt-snowflake~={self.version.major_minor_patch}')
-                pip_args.append(f'dbt-bigquery~={self.version.major_minor_patch}')
-        logger.info(f"Installing dbt {self.version.pypi_version} from {package_source} into `{self.venv_directory}`.")
+                package_source = "the Python Package Index"
+                if self.env.simulate_release_date:
+                    package_metadata = get_pypi_package_metadata('dbt')
+                    release_date = date.fromisoformat(package_metadata['releases'][self.version.pypi_version][0]['upload_time'][:10])
+                    logger.info(f"Simulating release date {release_date} for dbt {self.version}.")
+                    class ReleaseDateFilterPyPIRequestHandler(BaseDateFilterPyPIRequestHandler):
+                        date = release_date
+                    pip_filter_server = http.server.HTTPServer(('', 0), ReleaseDateFilterPyPIRequestHandler)
+                    pip_filter_port = pip_filter_server.socket.getsockname()[1]
+                    threading.Thread(target=pip_filter_server.serve_forever, daemon=True).start()
+                    pip_args.extend(['--index-url', f'http://localhost:{pip_filter_port}/simple'])
+                if self.version.pypi_version < '0.19.1':
+                    # Versions prior to 0.19.1 just specified agate>=1.6, but agate 1.6.2 introduced a dependency on PyICU
+                    # which causes installation problems, so exclude that like versions 0.19.1 and above do.
+                    pip_args.append('agate>=1.6,<1.6.2')
+                if self.version.pypi_version >= '0.15.0' < '0.16.0':
+                    # Versions ~=0.15.0 just specified Jinja2>=2.10, but dbt versions ~=0.15.0 are not compatible with
+                    # Jinja >= 3.0.0. https://github.com/dbt-labs/dbt-core/issues/2147
+                    pip_args.append('Jinja2<3')
+                if self.version.pypi_version >= '0.15.0' < '1.0.0':
+                    # Deprecation of soft_unicode in MarkupSafe==2.1.0 is not supported by Jinja2==2.11
+                    # https://github.com/dbt-labs/dbt-core/pull/4746
+                    pip_args.append('MarkupSafe==2.0.1')
 
-        logger.debug(f"Running `{pip}` with arguments {pip_args}.")
-        pip_result = subprocess.run([pip, *pip_args])
-        if pip_result.returncode != 0:
-            raise DbtenvError(f"Failed to install dbt {self.version.pypi_version} from {package_source} into `{self.venv_directory}`.")
+                pip_args.append(self.version.pip_specifier)
+            logger.info(f"Installing {self.version.pip_specifier} from {package_source} into `{self.venv_directory}`.")
 
-        logger.info(f"Successfully installed dbt {self.version.pypi_version} from {package_source} into `{self.venv_directory}`.")
+            logger.info(f"Running `{pip}` with arguments {pip_args}.")
+            pip_result = subprocess.run([pip, *pip_args])
+            if pip_result.returncode != 0:
+                raise DbtenvError(f"Failed to install dbt {self.version.pypi_version} from {package_source} into `{self.venv_directory}`.")
+        except Exception as e:
+            shutil.rmtree(self.venv_directory)
+            raise(e)
+
+        logger.info(f"Successfully installed {self.version} from {package_source} into `{self.venv_directory}`.")
 
     def _check_python_compatibility(self, python: str) -> None:
         python_version_result = subprocess.run([python, '--version'], stdout=subprocess.PIPE)
@@ -117,11 +171,11 @@ class PipDbt(Dbt):
         python_major_version = int(python_version_match['major_version'])
         python_minor_version = int(python_version_match['minor_version'])
 
-        if self.version < Version('0.20') and (python_major_version, python_minor_version) >= (3, 9):
+        if self.version.pypi_version < '0.20' and (python_major_version, python_minor_version) >= (3, 9):
             raise DbtenvError(
                 f"Python {python_version} is being used, but dbt versions before 0.20.0 aren't compatible with Python 3.9 or above."
             )
-        elif self.version < Version('0.15') and (python_major_version, python_minor_version) >= (3, 8):
+        elif self.version.pypi_version < '0.15' and (python_major_version, python_minor_version) >= (3, 8):
             raise DbtenvError(
                 f"Python {python_version} is being used, but dbt versions before 0.15 aren't compatible with Python 3.8 or above."
             )
@@ -184,25 +238,12 @@ class PipDbt(Dbt):
         if not self.is_installed():
             raise DbtenvError(f"No dbt {self.version.pypi_version} installation found in `{self.venv_directory}`.")
 
-        if force or dbtenv.string_is_true(input(f"Uninstall dbt {self.version.pypi_version} from `{self.venv_directory}`? ")):
+        if force or dbtenv.string_is_true(input(f"Uninstall `{self.venv_directory}`? ")):
             shutil.rmtree(self.venv_directory)
             self._executable = None
             logger.info(f"Successfully uninstalled dbt {self.version.pypi_version} from `{self.venv_directory}`.")
 
 
-def get_pypi_package_metadata(package: str) -> str:
-    package_json_url = f'https://pypi.org/pypi/{package}/json'
-    logger.debug(f"Fetching {package} package metadata from {package_json_url}.")
-    with urllib.request.urlopen(package_json_url) as package_json_response:
-        return json.load(package_json_response)
-
-
-def get_pypi_dbt_versions() -> List[Version]:
-    package_metadata = get_pypi_package_metadata('dbt')
-    possible_versions = ((Version(version), files) for version, files in package_metadata['releases'].items())
-    return [version for version, files in possible_versions if any(not file['yanked'] for file in files)]
-
-
 class BaseDateFilterPyPIRequestHandler(http.server.BaseHTTPRequestHandler):
     """
     HTTP request handler that proxies PEP 503-compliant requests to pypi.org and excludes files uploaded after self.date.
